tock: Theory of Computing toolKit
=================================

Tock stands for Theory Of Computing toolKit. It can simulate the
automata taught in standard theory of computation courses
(deterministic and nondeterministic finite automata, pushdown
automata, and Turing machines). It can also simulate many extensions,
like multiple stacks or tapes.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tutorial/index.rst
   reference/index.rst

Indexes
=======

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
